FunctionParam

Enum FunctionParam 

pub enum FunctionParam {
    In(FunctionParamIn),
    Out(FunctionParamOut),
    InOut(FunctionParamInOut),
    Variadic(FunctionParamVariadic),
    Table(FunctionParamTable),
}
function parameter type

Variants



In(FunctionParamIn)

Input parameter



Out(FunctionParamOut)

output parameter



InOut(FunctionParamInOut)

input output parameter



Variadic(FunctionParamVariadic)

variadic parameter



Table(FunctionParamTable)

table parameter

Implementations

Source

impl FunctionParam

pub fn analyze<TParseContext>( context: TParseContext, param: FunctionParameter, tokens: &IVec<ScanToken>, ) -> Result<(FunctionParam, TParseContext), AnalysisError>
where TParseContext: ParseContext,

analyze syntax node

Errors

Returns AnalysisError when the function parameter mode or type is missing or invalid.

Source

impl FunctionParam

pub fn analyze_as_column_definition( param: &FunctionParameter, ) -> Result<ColumnDefinition, AnalysisError>

analyze crate::syn::FunctionParameter as column definition

Errors

Returns AnalysisError when the parameter is missing its type or uses an invalid identifier.

pub fn is_output_param(param: &FunctionParameter) -> Result<bool, AnalysisError>

test paramter is a output param

Errors

Returns AnalysisError when the parameter mode is missing.

Source

impl FunctionParam

pub fn new_input_param( name: &Option<String>, param_type: &Option<TypeReference>, default_expr: &Option<SemScalarExpr>, ) -> Self

create new input parameter instance

Source

impl FunctionParam

pub fn new_output_param( name: &Option<String>, param_type: &Option<TypeReference>, ) -> Self

create new output parameter instance

Source

impl FunctionParam

pub fn new_variadig_param( name: &Option<String>, param_type: &Option<TypeReference>, ) -> Self

create new variadic parameter

Source

impl FunctionParam

pub fn get_type(&self) -> Option<&TypeReference>

get a type

pub fn append_returning_column(&self, column_collection: &mut ColumnCollection)

append returning column to column collecttion

pub fn collect_output_params_as_columns( params: &Vec<FunctionParameter>, ) -> Result<Option<ColumnCollection>, AnalysisError>

analyze output parameter as column collection

Errors

Returns AnalysisError if any parameter fails to parse.

pub fn bind_arg( &self, arg_types: &mut ArgumentBindingCollection, ) -> Result<ParameterBindResult, TypeError>

bind argument to function parameter

Errors

Propagates [TypeError] when binding fails.

pub fn collect_simple( &self, context: &mut SimpleInferContext, bind: &ParameterBindResult, ) -> Result<(), TypeError>

collect simple infer parameters

Errors

Returns [TypeError] if inferring argument types fails.

pub fn collect_common( &self, context: &mut CommonInferContext, bind: &ParameterBindResult, ) -> Result<(), TypeError>

collect common infer parameters

Errors

Returns [TypeError] if type inference fails.

pub fn apply_simple_infer_result(&mut self, simple_infer_result: &TypeReference)

apply simple infer result

pub fn apply_common_infer_result(&mut self, common_infer_result: &TypeReference)

apply common infer result

pub fn field_definition(&self) -> Option<CompositeFieldDefinition>

get composite type field definition for this parameter

pub fn test_castability_one<TParseContext>( &self, context: &TParseContext, source_type: &Option<TypeReference>, ) -> Result<i32, TypeError>
where TParseContext: ParseContext,

tests implicit cast is avaiable

Errors

Returns [TypeError] when an implicit cast cannot be resolved.

pub fn test_castability_variadic<TParseContext>( &self, context: &TParseContext, source_types: &IVec<Option<TypeReference>>, ) -> Result<i32, TypeError>
where TParseContext: ParseContext,

tests implicit cast is avaiable for variadic arguments

Errors

Returns [TypeError] when any argument cannot be implicitly cast.