pub struct CreateTable { /* private fields */ }Expand description
create table SQL statement
Implementations
Sourceimpl CreateTable
impl CreateTable
Sourcepub fn new(name: TableName, columns: Vec<ColumnDefinition>) -> Self
pub fn new(name: TableName, columns: Vec<ColumnDefinition>) -> Self
new instance with column definitions
Sourcepub fn get_column_def(
&self,
column_name: &ColumnName,
) -> Option<&ColumnDefinition>
pub fn get_column_def( &self, column_name: &ColumnName, ) -> Option<&ColumnDefinition>
get column definition by column name
Sourcepub fn get_column_def_with_skip_count(
&self,
column_name: &ColumnName,
skip_count: usize,
) -> Option<&ColumnDefinition>
pub fn get_column_def_with_skip_count( &self, column_name: &ColumnName, skip_count: usize, ) -> Option<&ColumnDefinition>
Look up a column definition by original column name, ignoring the first skip_count columns.
This is used to implement PostgreSQL’s behavior for a table alias with a column alias list:
SELECT ... FROM users AS u(id, name);When a column alias list is present, the original names of the first N columns (N = the length of the alias list) are not visible through that alias. Only the alias names are visible for those columns. Columns after the first N keep their original names.
For example, if users has at least two columns and the 1st column is named user_id,
then u.user_id is not accessible when skip_count >= 1 (e.g. u(id, name) makes skip_count = 2).
However, columns after the first skip_count columns are still accessible by their original names.
Sourcepub fn get_column_at(&self, column_index: usize) -> Option<&ColumnDefinition>
pub fn get_column_at(&self, column_index: usize) -> Option<&ColumnDefinition>
get column definition by index
Sourcepub fn has_column(&self, column: &ColumnName) -> bool
pub fn has_column(&self, column: &ColumnName) -> bool
check column existing
Sourcepub fn apply_alter(
&mut self,
alter_table: &AlterTable,
) -> Result<Vec<ImplicitChange>, AnalysisError>
pub fn apply_alter( &mut self, alter_table: &AlterTable, ) -> Result<Vec<ImplicitChange>, AnalysisError>
apply alter table statement
Sourcepub fn primary_key_columns(&self) -> Vec<&ColumnName>
pub fn primary_key_columns(&self) -> Vec<&ColumnName>
get primary key column names